@@ -213,6 +213,7 @@ date = new (function () {
     var pats = [];
     var dts = [];
     var str = format;
+    var key;
 
     // Allow either Date obj or UTC stamp
     d = typeof dt == 'number' ? new Date(dt) : dt;
@@ -652,14 +653,16 @@ date = new (function () {
                  Date objects
     @param {String} val The string to convert to a Date
   */
-  this.parse = function (val) {
+  this.parse = function (val, options) {
     var dt
+      , opts = options || {}
       , matches
       , reordered
       , off
       , posOff
       , offHours
       , offMinutes
+      , offSeconds
       , curr
       , stamp
       , utc;
@@ -720,23 +723,43 @@ date = new (function () {
         if (off) {
           if (off == 'Z') {
             utc = true;
-            offMinutes = 0;
+            offSeconds = 0;
           }
           else {
             utc = false;
-            off = off.replace(/\+|-|:/g, '');
+            // Convert from extended to basic if necessary
+            off = off.replace(/:/g, '');
+            // '+0000' will still be zero
             if (parseInt(off, 10) === 0) {
               utc = true;
             }
             else {
               posOff = off.indexOf('+') === 0;
+              // Strip plus or minus
               off = off.substr(1);
-              off = off.split(':');
-              offHours = parseInt(off[0], 10);
-              offMinutes = parseInt(off[1], 10) || 0;
-              offMinutes += (offHours * 60);
+
+              offHours = parseInt(off.substr(0, 2), 10);
+
+              offMinutes = off.substr(2, 2);
+              if (offMinutes) {
+                offMinutes = parseInt(offMinutes, 10);
+              }
+              else {
+                offMinutes = 0;
+              }
+
+              offSeconds = off.substr(4, 2);
+              if (offSeconds) {
+                offSeconds = parseInt(offSeconds, 10);
+              }
+              else {
+                offSeconds = 0;
+              }
+
+              offSeconds += (offMinutes * 60)
+              offSeconds += (offHours * 60 * 60);
               if (!posOff) {
-                offMinutes = 0 - offMinutes;
+                offSeconds = 0 - offSeconds;
               }
             }
           }
@@ -755,15 +778,40 @@ date = new (function () {
             dt['setUTC' + _dateMethods[i]](curr);
           }
           // Add any offset
-          dt.setMinutes(dt.getMinutes() - offMinutes);
+          dt.setSeconds(dt.getSeconds() - offSeconds);
         }
         // Otherwise we know nothing about the offset, just iterate the
         // array and set each date property using regular setters
         else {
+          var lastValIndex;
           for (var i = matches.length - 1; i > -1; i--) {
-            curr = parseInt(matches[i], 10) || 0;
+            if (matches[i]) {
+              curr = parseInt(matches[i], 10);
+              if (typeof lastValIndex == 'undefined') {
+                lastValIndex = i;
+              }
+            }
+            else {
+              curr = 0;
+            }
             dt['set' + _dateMethods[i]](curr);
           }
+          if (opts.setMax) {
+            for (var i = lastValIndex + 1, ii = matches.length; i < ii; i++) {
+              switch (i) {
+                case 3:
+                  dt['set' + _dateMethods[i]](23);
+                  break;
+                case 4:
+                case 5:
+                  dt['set' + _dateMethods[i]](59);
+                  break;
+                case 6:
+                  dt.setMilliseconds(999);
+                  break;
+              }
+            }
+          }
         }
       }
 
