@@ -43,7 +43,6 @@ var logger = new (function () {
 
 var fileUtils = new (function () {
   var _copyFile
-    , _copyDir
     , _readDir
     , _rmDir
     , _watch;
@@ -89,30 +88,34 @@ var fileUtils = new (function () {
         targetDir = path.join(to, filename);
         // We don't care if the target dir already exists
         try {
-          fs.mkdirSync(targetDir, options.mode || 0755);
+          fs.mkdirSync(targetDir, fromStat.mode & 07777);
         }
         catch(e) {
-          if (e.code != 'EEXIST') {
+          if (e.code !== 'EEXIST') {
             throw e;
           }
         }
         for (var i = 0, ii = dirContents.length; i < ii; i++) {
-          //console.log(dirContents[i]);
-          _copyFile(path.join(from, dirContents[i]), targetDir);
+          _copyFile(path.join(from, dirContents[i]), targetDir, {preserveMode: options.preserveMode});
         }
       }
       // Copying a file
       else {
         content = fs.readFileSync(from);
-        // Copy into dir
+        var mode = fromStat.mode & 07777;
+        var targetFile = to;
+
         if (toStat.isDirectory()) {
-          //console.log('copy into dir ' + to);
-          fs.writeFileSync(path.join(to, filename), content);
+          targetFile = path.join(to, filename);
         }
-        // Overwrite file
-        else {
-          //console.log('overwriting ' + to);
-          fs.writeFileSync(to, content);
+
+        var fileExists = fs.existsSync(targetFile);
+        fs.writeFileSync(targetFile, content);
+
+        // If the file didn't already exist, use the original file mode.
+        // Otherwise, only update the mode if preserverMode is true.
+        if(!fileExists || options.preserveMode) {
+          fs.chmodSync(targetFile, mode);
         }
       }
     }
@@ -122,10 +125,6 @@ var fileUtils = new (function () {
     }
   };
 
-  _copyDir = function (from, to, opts) {
-    var createDir = opts.createDir;
-  };
-
   // Return the contents of a given directory
   _readDir = function (dirPath) {
     var dir = path.normalize(dirPath)
@@ -165,12 +164,21 @@ var fileUtils = new (function () {
     paths = fs.readdirSync(dir);
     paths.forEach(function (p) {
       var curr = path.join(dir, p);
-      var stat = fs.statSync(curr);
+      var stat = fs.lstatSync(curr);
       if (stat.isDirectory()) {
         _rmDir(curr);
       }
       else {
-        fs.unlinkSync(curr);
+        try {
+          fs.unlinkSync(curr);
+        } catch(e) {
+          if (e.code === 'EPERM') {
+            fs.chmodSync(curr, parseInt(666, 8));
+            fs.unlinkSync(curr);
+          } else {
+            throw e;
+          }
+        }
       }
     });
     fs.rmdirSync(dir);
@@ -237,13 +245,15 @@ var fileUtils = new (function () {
     @param {String} toPath The destination path to copy to
     @param {Object} opts Options to use
       @param {Boolean} [opts.silent] If false then will log the command
+      @param {Boolean} [opts.preserveMode] If target file already exists, this
+        determines whether the original file's mode is copied over. The default of
+        false mimics the behavior of the `cp` command line tool. (Default: false)
   */
   this.cpR = function (fromPath, toPath, options) {
     var from = path.normalize(fromPath)
       , to = path.normalize(toPath)
       , toStat
       , doesNotExistErr
-      , paths
       , filename
       , opts = options || {};
 
@@ -317,7 +327,7 @@ var fileUtils = new (function () {
       currPath = path.join(currPath, next);
       try {
         //console.log('making ' + currPath);
-        fs.mkdirSync(currPath, mode || 0755);
+        fs.mkdirSync(currPath, mode || parseInt(755, 8));
       }
       catch(e) {
         if (e.code != 'EEXIST') {
@@ -361,7 +371,7 @@ var fileUtils = new (function () {
       logger.log('rm -rf ' + p);
     }
     try {
-      stat = fs.statSync(p);
+      stat = fs.lstatSync(p);
       if (stat.isDirectory()) {
         _rmDir(p);
       }
@@ -527,6 +537,7 @@ var fileUtils = new (function () {
     @param {String} message An option message to throw if the module doesn't exist
   */
   this.requireLocal = function (module, message) {
+    var dep;
     // Try to require in the application directory
     try {
       dep = require(path.join(process.cwd(), 'node_modules', module));
